@@ -220,8 +220,6 @@ enum Command {
             visible_alias = "ctx"
         )]
         context: Option<String>,
-        #[structopt(help = "Skip running 'helm uninstall'", long)]
-        skip_helm: bool,
     },
 
     #[structopt(
@@ -555,7 +553,10 @@ enum Command {
     },
 
     #[structopt(about = "Save default configuration file", display_order(2000))]
-    SaveConfig,
+    SaveConfig {
+        #[structopt(help = "Save selected profile as default profile", long, short = "d")]
+        set_default_profile: bool,
+    },
 
     #[structopt(
         about = "Check for updates to statehub utility",
@@ -605,7 +606,7 @@ impl Command {
             Command::ListNodes { .. } => false,
             Command::ListPods { .. } => false,
             Command::ListRegions { .. } => false,
-            Command::SaveConfig => false,
+            Command::SaveConfig { .. } => false,
             Command::SelfUpdate => false,
         }
     }
@@ -721,12 +722,11 @@ impl Cli {
                 force,
                 name,
                 context,
-                skip_helm,
             } => {
                 let names = vec![name];
                 let contexts = context.into_iter().collect();
                 let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
-                let helm = k8s::Helm::new(skip_helm);
+                let helm = k8s::Helm::skip();
 
                 statehub.unregister_cluster(kubectls, helm, force).await
             }
@@ -846,7 +846,9 @@ impl Cli {
             Command::ListNodes { context } => statehub.list_nodes(context).await,
             Command::ListPods { context } => statehub.list_pods(context).await,
             Command::ListRegions { context, zone } => statehub.list_regions(context, zone).await,
-            Command::SaveConfig => statehub.save_config().await,
+            Command::SaveConfig {
+                set_default_profile,
+            } => statehub.save_config(set_default_profile).await,
             Command::SelfUpdate => statehub.self_update().await,
         }
     }
@@ -914,7 +916,7 @@ impl StateHub {
 
         let token = self.input(prompt)?;
 
-        self.config.clone().set_token(Some(token)).save()?;
+        self.config.clone().set_token(Some(token)).save(false)?;
         Ok(())
     }
 
@@ -1379,8 +1381,8 @@ impl StateHub {
         Ok(())
     }
 
-    async fn save_config(&self) -> anyhow::Result<()> {
-        self.config.save().and_then(|path| {
+    async fn save_config(&self, set_default_profile: bool) -> anyhow::Result<()> {
+        self.config.save(set_default_profile).and_then(|path| {
             self.inform(format_args!("Saving config to {}", path.display()))
                 .context("Inform")
         })
