@@ -105,8 +105,13 @@ impl StateHub {
                 .await?;
         }
 
-        self.helm_install_helper(&kubectl, &cluster, register_cluster)
-            .await?;
+        self.helm_install_helper(
+            &kubectl,
+            &cluster,
+            &register_cluster.namespace,
+            &register_cluster.helm,
+        )
+        .await?;
 
         cluster.print(&self.stdout, &self.style, self.json)
     }
@@ -114,10 +119,24 @@ impl StateHub {
     pub(super) async fn unregister_cluster_helper(
         &self,
         kubectl: k8s::Kubectl,
+        helm: k8s::Helm,
     ) -> anyhow::Result<()> {
         let name = kubectl.cluster_name();
+        let cluster = self.api.get_cluster(name).await?;
+
+        let (statehub_cluster_name, namespace) =
+            kubectl.get_statehub_cluster_name_and_namespace().await?;
+        anyhow::ensure!(
+            *name == statehub_cluster_name,
+            "Cluster name mismatch: K8s thinks it is '{}', while Statehub thinks it is  '{}'",
+            statehub_cluster_name,
+            name,
+        );
         self.relinquish_states_helper(name).await?;
 
+        self.helm_uninstall_helper(&kubectl, &cluster, &namespace, &helm)
+            .await?;
+
         self.api
             .unregister_cluster(name)
             .await
@@ -431,14 +450,30 @@ or run following commands before running 'statehub register-cluster`
         &self,
         kubectl: &k8s::Kubectl,
         cluster: &v0::Cluster,
-        register_cluster: &RegisterCluster,
+        namespace: &str,
+        helm: &k8s::Helm,
     ) -> anyhow::Result<()> {
         let kube_context = kubectl.context();
-        let namespace = &register_cluster.namespace;
-        let (stdout, stderr) = register_cluster
-            .helm
-            .execute(cluster, kube_context, namespace)
-            .await?;
+        let commands = helm.install_command(cluster, Some(kube_context), namespace);
+
+        let (stdout, stderr) = helm.execute(commands).await?;
+
+        self.verbosely(stdout)?;
+        self.error(stderr)?;
+        Ok(())
+    }
+
+    pub(super) async fn helm_uninstall_helper(
+        &self,
+        kubectl: &k8s::Kubectl,
+        cluster: &v0::Cluster,
+        namespace: &str,
+        helm: &k8s::Helm,
+    ) -> anyhow::Result<()> {
+        let kube_context = kubectl.context();
+        let commands = helm.uninstall_command(cluster, Some(kube_context), namespace);
+
+        let (stdout, stderr) = helm.execute(commands).await?;
 
         self.verbosely(stdout)?;
         self.error(stderr)?;
